==> digikam-3.0.0-beta3.tar.bz2: digikam-3.0.0-beta3/extra/kipi-plugins/vkontakte/kipiplugin_vkontakte.desktop.cmake <==
[Desktop Entry]
Name=VKontakte.ru Exporter
Name[ca]=Exportador a VKontakte.ru
Name[ca@valencia]=Exportador a VKontakte.ru
Name[cs]=Exportér VKontakte.ru
Name[da]=Eksportør til VKontakte.ru
Name[de]=VKontakte.ru-Export
Name[el]=Εξαγωγέας VKontakte.ru 
Name[es]=Exportar a VKontakte.ru
Name[et]=VKontakte.ru eksportija
Name[ga]=Easpórtálaí VKontakte.ru
Name[gl]=Exportador a VKontackte.ru
Name[hu]=VKontakte.ru exportáló
Name[is]=VKontakte.ru útflutningstól
Name[it]=Esportatore a VKontakte.ru
Name[km]=កម្មវិធី​នាំចេញ VKontakte.ru
Name[nb]=VKontakte.ru eksporterer
Name[nl]=Exportprogramma van VKontakte.ru
Name[pl]=Eksporter VKontakte.ru
Name[pt]=Exportação para o VKontakte.ru
Name[pt_BR]=Exportação para o VKontakte.ru
Name[ru]=Экспорт в VKontakte.ru
Name[sl]=Izvoz v VKontakte.ru
Name[sv]=Export till VKontakte.ru
Name[uk]=Експорт до VKontakte.ru
Name[x-test]=xxVKontakte.ru Exporterxx
Name[zh_TW]=Vkontakte.ru 匯出器
Comment=A tool to export images to the VKontakte.ru social network
Comment[ca]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[ca@valencia]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[cs]=Nástroj pro export obrázků do sociální sítě VKontakte.ru
Comment[da]=Et værktøj til at eksportere billeder til det sociale netværk VKontakte.ru
Comment[de]=Ein Werkzeug, um Bilder zum Sozialen Netzwerk „VKontakte“ zu exportieren.
Comment[el]=Ένα εργαλείο εξαγωγής εικόνων στο κοινωνικό δίκτυο VKontakte.ru
Comment[es]=Herramienta para exportar imágenes a la red social VKontakte.ru
Comment[et]=Tööriist piltide eksportimiseks VKontakte.ru sotsiaalvõrgustikku
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí an líonra sóisialta VKontakte.ru
Comment[gl]=Unha ferramenta para exportar imaxes á rede social VKontakte.ru
Comment[hu]=Egy eszköz képek exportálásához a VKontakte.ru közösségi hálózatba
Comment[is]=Verkfæri til að senda myndir VKontakte.ru samskiptanetið
Comment[it]=Uno strumento per esportare immagini alla rete sociale VKontakte.ru
Comment[km]=ឧបករណ៍​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​បណ្ដាញ​សង្គម VKontakte.ru
Comment[nb]=Et verktøy for å eksportere bilder til det sosiale nettverket VKontakte.ru
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar het VKontakte.ru sociale netwerk
Comment[pl]=Narzędzie do eksportowania obrazów do sieci społecznej VKontakte.ru
Comment[pt]=Uma ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[pt_BR]=Uma ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[ru]=Инструмент для экспорта изображений в социальную сеть VKontakte.ru
Comment[sl]=Orodje za izvoz slik v družabno omrežje VKontakte.ru
Comment[sv]=Ett verktyg för att exportera bilder till sociala nätverket VKontakte.ru
Comment[uk]=Інструмент для експорту зображень до соціальної мережі VKontakte.ru
Comment[x-test]=xxA tool to export images to the VKontakte.ru social networkxx
Comment[zh_TW]=匯出影像到 Vkontakte.ru 社交網路的工具
Type=Service
Icon=preferences-web-browser-shortcuts
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_vkontakte
author=Alexander Potashev, aspotashev@gmail.com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}

==> digikam-3.3.0-beta3.tar.bz2: digikam-3.3.0-beta3/extra/kipi-plugins/vkontakte/kipiplugin_vkontakte.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=VKontakte.ru Exporter
Name=VKontakte.ru Exporter
Name[ca]=Exportador a VKontakte.ru
Name[ca@valencia]=Exportador a VKontakte.ru
Name[cs]=Exportér VKontakte.ru
Name[da]=Eksportør til VKontakte.ru
Name[de]=VKontakte.ru-Export
Name[el]=Εξαγωγέας VKontakte.ru 
Name[es]=Exportar a VKontakte.ru
Name[et]=VKontakte.ru eksportija
Name[fr]=Export VKontakte.ru
Name[ga]=Easpórtálaí VKontakte.ru
Name[gl]=Exportador a VKontackte.ru
Name[hu]=VKontakte.ru exportáló
Name[is]=VKontakte.ru útflutningstól
Name[it]=Esportatore a VKontakte.ru
Name[km]=កម្មវិធី​នាំចេញ VKontakte.ru
Name[nb]=VKontakte.ru eksporterer
Name[nl]=Exportprogramma van VKontakte.ru
Name[pl]=Eksporter VKontakte.ru
Name[pt]=Exportação para o VKontakte.ru
Name[pt_BR]=Exportação para o VKontakte.ru
Name[ru]=Экспорт в VKontakte.ru
Name[sl]=Izvoz v VKontakte.ru
Name[sv]=Export till VKontakte.ru
Name[uk]=Експорт до VKontakte.ru
Name[x-test]=xxVKontakte.ru Exporterxx
Name[zh_TW]=Vkontakte.ru 匯出器
Comment=A tool to export images to the VKontakte.ru social network
Comment[ca]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[ca@valencia]=Una eina per exportar imatges a la xarxa social VKontakte.ru
Comment[cs]=Nástroj pro export obrázků do sociální sítě VKontakte.ru
Comment[da]=Et værktøj til at eksportere billeder til det sociale netværk VKontakte.ru
Comment[de]=Ein Werkzeug, um Bilder zum Sozialen Netzwerk „VKontakte“ zu exportieren.
Comment[el]=Ένα εργαλείο εξαγωγής εικόνων στο κοινωνικό δίκτυο VKontakte.ru
Comment[es]=Herramienta para exportar imágenes a la red social VKontakte.ru
Comment[et]=Tööriist piltide eksportimiseks VKontakte.ru sotsiaalvõrgustikku
Comment[fr]=Outil pour l'exportation vers le réseau social VKontakte.ru
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí an líonra sóisialta VKontakte.ru
Comment[gl]=Unha ferramenta para exportar imaxes á rede social VKontakte.ru
Comment[hu]=Egy eszköz képek exportálásához a VKontakte.ru közösségi hálózatba
Comment[is]=Verkfæri til að senda myndir VKontakte.ru samskiptanetið
Comment[it]=Uno strumento per esportare immagini alla rete sociale VKontakte.ru
Comment[km]=ឧបករណ៍​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​បណ្ដាញ​សង្គម VKontakte.ru
Comment[nb]=Et verktøy for å eksportere bilder til det sosiale nettverket VKontakte.ru
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar het VKontakte.ru sociale netwerk
Comment[pl]=Narzędzie do eksportowania obrazów do sieci społecznej VKontakte.ru
Comment[pt]=Uma ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[pt_BR]=Uma ferramenta para exportar imagens para a rede social VKontakte.ru
Comment[ru]=Инструмент для экспорта изображений в социальную сеть VKontakte.ru
Comment[sl]=Orodje za izvoz slik v družabno omrežje VKontakte.ru
Comment[sv]=Ett verktyg för att exportera bilder till sociala nätverket VKontakte.ru
Comment[uk]=Інструмент для експорту зображень до соціальної мережі VKontakte.ru
Comment[x-test]=xxA tool to export images to the VKontakte.ru social networkxx
Comment[zh_TW]=匯出影像到 Vkontakte.ru 社交網路的工具
Type=Service
Icon=preferences-web-browser-shortcuts
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_vkontakte
author=Alexander Potashev, aspotashev@gmail.com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
